@@ -55,116 +55,116 @@ These commands are available by default.
 
 =head2 C<help>
 
-  % mojo
-  % mojo help
+  $ mojo
+  $ mojo help
 
 List available commands with short descriptions.
 
-  % mojo help <command>
+  $ mojo help <command>
 
 List available options for the command with short descriptions.
 
 =head2 C<cgi>
 
-  % mojo cgi
-  % script/myapp cgi
+  $ mojo cgi
+  $ script/myapp cgi
 
 Start application with CGI backend.
 
 =head2 C<daemon>
 
-  % mojo daemon
-  % script/myapp daemon
+  $ mojo daemon
+  $ script/myapp daemon
 
 Start application with standalone HTTP 1.1 server backend.
 
 =head2 C<eval>
 
-  % mojo eval 'print app->home'
-  % script/myapp eval 'print app->home'
+  $ mojo eval 'print app->home'
+  $ script/myapp eval 'print app->home'
 
 Run code against application.
 
 =head2 C<fastcgi>
 
-  % mojo fastcgi
-  % script/myapp fastcgi
+  $ mojo fastcgi
+  $ script/myapp fastcgi
 
 Start application with FastCGI backend.
 
 =head2 C<generate>
 
-  % mojo generate
-  % mojo generate help
+  $ mojo generate
+  $ mojo generate help
 
 List available generator commands with short descriptions.
 
-  % mojo generate help <generator>
+  $ mojo generate help <generator>
 
 List available options for generator command with short descriptions.
 
 =head2 C<generate app>
 
-  % mojo generate app <AppName>
+  $ mojo generate app <AppName>
 
 Generate application directory structure for a fully functional
 L<Mojolicious> application.
 
 =head2 C<generate gitignore>
 
-  % mojo generate gitignore
+  $ mojo generate gitignore
 
 Generate C<.gitignore> file.
 
 =head2 C<generate hypnotoad>
 
-  % mojo generate hypnotoad
+  $ mojo generate hypnotoad
 
 Generate C<hypnotoad.conf> file.
 
 =head2 C<generate lite_app>
 
-  % mojo generate lite_app
+  $ mojo generate lite_app
 
 Generate a fully functional L<Mojolicious::Lite> application.
 
 =head2 C<generate makefile>
 
-  % mojo generate makefile
+  $ mojo generate makefile
 
 Generate C<Makefile.PL> file for application.
 
 =head2 C<get>
 
-  % mojo get http://mojolicio.us
-  % script/myapp get /foo
+  $ mojo get http://mojolicio.us
+  $ script/myapp get /foo
 
 Perform GET request to remote host or local application.
 
 =head2 C<inflate>
 
-  % myapp.pl inflate
+  $ myapp.pl inflate
 
 Turn embedded files from the C<DATA> section into real files.
 
 =head2 C<routes>
 
-  % myapp.pl routes
-  % script/myapp routes
+  $ myapp.pl routes
+  $ script/myapp routes
 
 List application routes.
 
 =head2 C<test>
 
-  % mojo test
-  % script/myapp test
-  % script/myapp test t/foo.t
+  $ mojo test
+  $ script/myapp test
+  $ script/myapp test t/foo.t
 
 Runs application tests from the C<t> directory.
 
 =head2 C<version>
 
-  % mojo version
+  $ mojo version
 
 List version information for installed core and optional modules, very useful
 for debugging.
