@@ -123,8 +123,9 @@ sub register {
       );
 
       # Try to find a title
-      my $title = 'Perldoc';
-      $dom->find('h1 + p')->until(sub { $title = shift->text });
+      my $title;
+      $dom->find('h1 + p')->each(sub { $title ||= shift->text });
+      $title ||= 'Perldoc';
 
       # Combine everything to a proper response
       $self->content_for(mojobar => $self->include(inline => $MOJOBAR));
