@@ -34,23 +34,17 @@ sub load_plugin {
     $name = $new;
   }
 
-  # Module
-  if ($name =~ /^[A-Z]/ && $self->_load($name)) { return $name->new }
-
-  # Search plugin by name
-  else {
-
-    # Class
-    my $class = $name;
-    camelize $class if $class =~ /^[a-z]/;
-
-    # Try all namspaces
-    for my $namespace (@{$self->namespaces}) {
-      my $module = "${namespace}::$class";
-      return $module->new if $self->_load($module);
-    }
+  # Try all namspaces
+  my $class = $name;
+  camelize $class if $class =~ /^[a-z_]+$/;
+  for my $namespace (@{$self->namespaces}) {
+    my $module = "${namespace}::$class";
+    return $module->new if $self->_load($module);
   }
 
+  # Full module name
+  return $name->new if $self->_load($name);
+
   # Not found
   die qq/Plugin "$name" missing, maybe you need to install it?\n/;
 }
